/* Copyright (C) 2000-2003 Damir Zucic */

/*=============================================================================

				print_version.c

Purpose:
	Print version information.

Input:
	No input.

Output:
	Version info printed to stdout.

Return value:
	No return value.

========includes:============================================================*/

#include <stdio.h>

/*======print version info:==================================================*/

void PrintVersion_ (void)
{
fprintf (stdout, "\n");
fprintf (stdout, "==================================\n");
fprintf (stdout, "garlic version 1.3\n");
fprintf (stdout, "Last revision: 2003/March/31\n");
fprintf (stdout, "==================================\n");
fprintf (stdout, "\n");
fprintf (stdout, "Compliant with PDB version 2.1");
fprintf (stdout, " (draft, October 25, 1996).\n");
fprintf (stdout,
	 "Copyright (C) 2000-2003 Damir Zucic (zucic@garlic.mefos.hr).\n");
fprintf (stdout, "Source code, documentation and binaries:\n");
fprintf (stdout, "\n=====================================\n");
fprintf (stdout, "  http://garlic.mefos.hr/garlic-1.3\n");
fprintf (stdout, "=====================================\n\n");
}

/*===========================================================================*/


